summaryrefslogtreecommitdiffstats
path: root/kjs/regexp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjs/regexp.cpp')
-rw-r--r--kjs/regexp.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kjs/regexp.cpp b/kjs/regexp.cpp
index 06defcc53..446cc7d3d 100644
--- a/kjs/regexp.cpp
+++ b/kjs/regexp.cpp
@@ -38,7 +38,7 @@ RegExp::UTF8SupportState RegExp::utf8Support = RegExp::Unknown;
RegExp::RegExp(const UString &p, int f)
: pat(p), flgs(f), m_notEmpty(false), valid(true), buffer(0), originalPos(0)
{
// Determine whether libpcre has unicode support if need be..
#ifdef PCRE_CONFIG_UTF8
if (utf8Support == Unknown) {
int supported;
@@ -56,7 +56,7 @@ RegExp::RegExp(const UString &p, int f)
// expects null termination..
UString intern;
const char* const nil = "\\x00";
- if (p.find('\\') >= 0 || p.find(KJS::UChar('\0')) >= 0) {
+ if (p.tqfind('\\') >= 0 || p.tqfind(KJS::UChar('\0')) >= 0) {
bool escape = false;
for (int i = 0; i < p.size(); ++i) {
UChar c = p[i];
@@ -64,13 +64,13 @@ RegExp::RegExp(const UString &p, int f)
escape = false;
// we only care about \u
if (c == 'u') {
// standard unicode escape sequence looks like \uxxxx but
// other browsers also accept less then 4 hex digits
unsigned short u = 0;
int j = 0;
for (j = 0; j < 4; ++j) {
- if (i + 1 < p.size() && Lexer::isHexDigit(p[i + 1].unicode())) {
- u = (u << 4) + Lexer::convertHex(p[i + 1].unicode());
+ if (i + 1 < p.size() && Lexer::isHexDigit(p[i + 1].tqunicode())) {
+ u = (u << 4) + Lexer::convertHex(p[i + 1].tqunicode());
++i;
} else {
// sequence incomplete. restore index.
@@ -222,7 +222,7 @@ void RegExp::prepareUtf8(const UString& s)
int *posOut = originalPos;
const UChar *d = s.data();
for (int i = 0; i != length; ++i) {
- unsigned short c = d[i].unicode();
+ unsigned short c = d[i].tqunicode();
int sequenceLen;
if (c < 0x80) {
@@ -38,7 +38,7 @@ RegExp::UTF8SupportState RegExp::utf8Support = RegExp::Unknown;
: pat(p), flgs(f), m_notEmpty(false), valid(true), buffer(0), originalPos(0)
{
- // Determine whether libpcre has unicode support if need be..
+ // Determine whether libpcre has tqunicode support if need be..
#ifdef PCRE_CONFIG_UTF8
if (utf8Support == Unknown) {
@@ -64,13 +64,13 @@ RegExp::RegExp(const UString &p, int f)
// we only care about \u
if (c == 'u') {
- // standard unicode escape sequence looks like \uxxxx but
+ // standard tqunicode escape sequence looks like \uxxxx but
// other browsers also accept less then 4 hex digits
unsigned short u = 0;